@@ -508,6 +508,10 @@ public final class TrapListenerImpl extends DataStringDisplay implements
 					SnmpPreference.EGPNEIGHBORLOS_OID)) {
 				snmpTrapOidValueDescription = "egpNeighborLoss" + "("
 						+ varBindValue.toString() + ")";
+			} else if (varBindValue.toString().equals(
+					SnmpPreference.ENTERPRISESPECIFIC_OID)) {
+				snmpTrapOidValueDescription = "enterpriseSpecific" + "("
+						+ varBindValue.toString() + ")";
 			} else {
 				/*
 				 * snmpTraps(OID = 1.3.6.1.6.3.1.1.5) O[vłȂꍇsnmpTrapOIDPair
